#!/bin/bash
#
# Zope    This shell script takes care of starting and stopping
#         Zope.
#
# chkconfig: 345 95 05
# description: Zope is the framework needed to run Plone.

# Source function library.
. /etc/rc.d/init.d/functions
RETVAL=0

# Who are we?
Prog="Zope"
progBIN="zope"

# Source environment variables
. /etc/$Prog.conf &>/dev/null || {
  echo "Configuration file /etc/$Prog.conf missing - run install.sh"
  exit 1
}
[ -z "$ZOPEhome" ] && {
  echo "\$ZOPEhome not set in /etc/$Prog.conf - run install.sh"
  exit 1
}
. $ZOPEhome/$Prog.conf.defaults &>/dev/null || {
  echo "Default configuration $ZOPEhome/$Prog.conf.defaults missing - run install.sh"
  exit 1
}
zopestart() {
  local RETVAL=0
  echo -n "Starting $Prog"
  [ -f $ZOPEhome/var/Z2.pid ] && {
    echo -n " [ already running ]"
    echo_passed
    echo
    exit 1
  }

  # Set umask
  umask 077

  # Logging
  ZLOGFILE=$EVENT_LOG_FILE
  [ -z "$ZLOGFILE" ] && ZLOGFILE=$STUPID_LOG_FILE
  [ -z "$ZLOGFILE" ] && EVENT_LOG_FILE=""
  export EVENT_LOG_FILE

  # Fire it up
  daemon $ZOPEhome/bin/python $ZOPEhome/z2.py -u $ZOPEuser -w $ZOPEportHTTP -f $ZOPEportFTP -m $ZOPEportMANAGE

  RETVAL=$?
  [ $RETVAL -eq 0 ] || { echo_failure ; exit $RETVAL ; }
  zopetouch
  echo_success
  echo
  return $RETVAL
}
zopestop() {
  local RETVAL=0
  gprintf "Stopping %s: " $Prog
  [ -f $ZOPEhome/var/Z2.pid ] || {
    echo_passed
    echo
    exit 1
  }
  kill `cat $ZOPEhome/var/Z2.pid` &>/dev/null
  RETVAL=$?
  sleep 5
  [ $RETVAL -eq 0 ] && echo_success || echo_failure
  echo
  clean
  return $RETVAL
}
zoperestart()     { 
  local RETVAL=0
  $0 stop
  zopestart
  RETVAL=$?
  $0 status
  return $RETVAL
}  
zopecondrestart() { [ -f /var/lock/subsys/$progBIN ] && zoperestart || : ; }
zopestatus() {
  local RETVAL=0
  echo -n "Status of Zope: "
  pythonPID=`pidof python`
  [ -z "$pythonPID" ] || pythonPID=" [ PY: $pythonPID ]"
  progPID=`cat "$ZOPEhome/var/Z2.pid" 2>/dev/null`
  if [ -z "$progPID" ]; then
    echo -n " [ No PID found ]"
    echo_passed
    RETVAL=1
  elif ps $progPID &>/dev/null; then 
    echo -n " [ PID: $progPID$pythonPID ]" 
  else
      echo -n " [ STALED, no instance found ]"
      echo_failure
      RETVAL=1
  fi
  [ $RETVAL -eq 0 ] && echo_success 
  echo
  return $RETVAL
}
zopetouch() {  
  touch /var/lock/subsys/$progBIN
  touch /var/run/$progBIN
}
zopeclean() {
  local RETVAL=1
  for i in \
    "$ZOPEhome/var/pcgi.soc" \
    "$ZOPEhome/var/Data.fs.lock" \
    "$ZOPEhome/var/zProcessManager.pid" \
    "$ZOPEhome/var/Z2.pid" \
    "/var/run/$progBIN" \
    "/var/lock/subsys/$progBIN"
  do 
    [ -e "$i" ] && { 
      RETVAL=0
      rm -f "$i"
    }
  done
  [ $RETVAL -eq 0 ] || echo_passed && echo_success
}
clean() {
  local RETVAL=0
  echo -n "Cleaning up:"
  if ! service $Prog status &>/dev/null ; then 
    zopeclean
    RETVAL=$?
  else
    echo -n " [ Zope is running?! ]"
    RETVAL=1
    echo_passed
  fi
  echo
  exit $RETVAL
}
zopeswitch() {
  echo -n "Switching Service $1 via chkconfig:"
  chkconfig Zope $1 2>/dev/null && echo_success || echo_failure
  echo
}
zopehelp() {
  gprintf "Usage: %s {start|stop|status|restart|condrestart|clean|on|off|list}\n" $0
}

# See how we were called.
case "$1" in
  start)       zopestart ;;
  stop)        zopestop ;;
  status)      zopestatus ;;
  restart)     zoperestart ;;
  condrestart) zopecondrestart ;;
  clean)       clean ;;
  on|off)      zopeswitch $1 ;;
  list|--list) chkconfig Zope --list ;;
  *)           zopehelp ; exit 1 ;;
esac
exit $?
